# Falconpunch

Rust bindings for Python [Overpunch](https://github.com/capitalrx/overpunch), a [signed overpunch](https://en.wikipedia.org/wiki/Signed_overpunch) support library suitable for interacting
with [Decimal](https://docs.python.org/3/library/decimal.html) values.

## Installing

```sh
$ pip install falconpunch
```

## Usage

To parse signed overpunch numbers:

```python
from decimal import Decimal
from falconpunch import convert_from_signed_format, extract

number = convert_from_signed_format("2258{", "s9(7)v99")
assert number == Decimal("225.80")

number = extract("2258{", 2)
assert number == Decimal("225.80")
```

To format values to signed overpunch:

```python
from decimal import Decimal
from falconpunch import convert_to_signed_format, format

formatted = convert_to_signed_format(Decimal("225.80"), "s9(7)v99")
assert formatted == "2258{"

formatted = format(Decimal("225.80"), 2)
assert formatted == "2258{"
```
