use overpunch::{
    convert_from_signed_format as rs_convert_from_signed_format,
    convert_to_signed_format as rs_convert_to_signed_format,
    extract as rs_extract,
    format as rs_format,
};
use pyo3::exceptions::PyValueError;
use pyo3::prelude::*;
use rust_decimal::Decimal;

#[pyfunction]
fn convert_from_signed_format(value: &str, field_format: &str) -> PyResult<Option<Decimal>> {
    return Ok(rs_convert_from_signed_format(value, field_format));
}

#[pyfunction]
fn convert_to_signed_format(value: Decimal, field_format: &str) -> PyResult<Option<String>> {
    return Ok(rs_convert_to_signed_format(value, field_format));
}

#[pyfunction]
fn extract(raw: &str, decimals: usize) -> PyResult<Decimal> {
    return rs_extract(raw, decimals).map_err(|e| PyValueError::new_err(e.to_string()));
}

#[pyfunction]
fn format(value: Decimal, decimals: usize) -> PyResult<String> {
    return rs_format(value, decimals).map_err(|e| PyValueError::new_err(e.to_string()));
}

#[pymodule]
fn falconpunch(m: &Bound<'_, PyModule>) -> PyResult<()> {
    m.add_function(wrap_pyfunction!(convert_from_signed_format, m)?)?;
    m.add_function(wrap_pyfunction!(convert_to_signed_format, m)?)?;
    m.add_function(wrap_pyfunction!(extract, m)?)?;
    m.add_function(wrap_pyfunction!(format, m)?)?;
    return Ok(());
}
